import * as vue from 'vue';
import { Plugin } from 'vue';
import { Router } from 'vue-router';

declare const authPlugin: Plugin;

interface Redirect {
    login: string;
    logout: string;
    home: string;
}
interface Endpoint {
    url: string;
    method: string;
}
interface Token {
    property: string;
    type: string;
    name: string;
    prefix: string;
}
interface User {
    propertyInLogin: string;
    propertyInFetch: string;
    propertyRole: string;
    propertyPermission: string;
    autoFetch: boolean;
}
declare type EndpointKey = 'login' | 'logout' | 'user';
interface AuthOptions {
    router: Router;
    fullPathRedirect: boolean;
    watchLoggedIn: boolean;
    baseUrl: string;
    redirect: Redirect;
    local: {
        endpoints: Record<EndpointKey, Endpoint | false>;
        token: Token;
        user: User;
    };
}
declare type MetaAuth = boolean | {
    role: string;
    permission: string;
};

declare const useAuth: (_options?: AuthOptions | undefined) => {
    user: vue.Ref<null>;
    loggedIn: vue.Ref<boolean>;
    login: (args: any) => Promise<void>;
    logout: (args?: any) => Promise<any>;
    setToken: (tokenValue: string) => void;
    getToken: () => any;
    getUser: () => null;
    setUser: (user: any) => void;
    getRole: () => string;
    isRole: (role: string) => boolean;
    getPermissions: () => string[];
    hasPermission: (permission: string) => boolean;
    resetState: () => void;
    fetchUser: () => Promise<any>;
};

declare const DEFAULT_OPTION: {
    fullPathRedirect: boolean;
    watchLoggedIn: boolean;
    redirect: {
        login: string;
        logout: string;
        home: string;
    };
    local: {
        endpoints: {
            login: {
                url: string;
                method: string;
            };
            logout: {
                url: string;
                method: string;
            };
            user: {
                url: string;
                method: string;
            };
        };
        token: {
            property: string;
            type: string;
            name: string;
            prefix: string;
        };
        user: {
            propertyInLogin: string;
            propertyInFetch: string;
            propertyRole: string;
            propertyPermission: string;
            autoFetch: boolean;
        };
    };
};

export { AuthOptions, DEFAULT_OPTION, Endpoint, EndpointKey, MetaAuth, Redirect, Token, User, authPlugin, useAuth };
